function varargout = DPARSFA(varargin)
%Data Processing Assistant for Resting-State fMRI (DPARSF) Advanced Edition (alias: DPARSFA) GUI by YAN Chao-Gan
%-----------------------------------------------------------
%	Copyright(c) 2009~2013
%	State Key Laboratory of Cognitive Neuroscience and Learning, Beijing Normal University
%   The Nathan Kline Institute for Psychiatric Research, 140 Old Orangeburg Road, Orangeburg, NY 10962; Child Mind Institute, 445 Park Avenue, New York, NY 10022; The Phyllis Green and Randolph Cowen Institute for Pediatric Neuroscience, New York University Child Study Center, New York, NY 10016
%	Written by YAN Chao-Gan
%	http://www.restfmri.net
% $mail     =ycg.yan@gmail.com
% $Version =2.0;
% $Date =20101025;
%-----------------------------------------------------------
% 	Mail to Author:  <a href="ycg.yan@gmail.com">YAN Chao-Gan</a> 
%   Last Modified by YAN Chao-Gan, 110505. Fixed an error in the future MATLAB version in "[pathstr, name, ext, versn] = fileparts...".

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @DPARSFA_OpeningFcn, ...
                   'gui_OutputFcn',  @DPARSFA_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before DPARSFA is made visible.
function DPARSFA_OpeningFcn(hObject, eventdata, handles, varargin)
    Release='V2.1_120101';
    
    if ispc
        UserName =getenv('USERNAME');
    else
        UserName =getenv('USER');
    end
    Datetime=fix(clock);
    fprintf('Welcome: %s, %.4d-%.2d-%.2d %.2d:%.2d \n', UserName,Datetime(1),Datetime(2),Datetime(3),Datetime(4),Datetime(5));
    fprintf('Data Processing Assistant for Resting-State fMRI (DPARSF) Advanced Edition (alias: DPARSFA). \nRelease=%s\n',Release);
    fprintf('Copyright(c) 2009~2013\nState Key Laboratory of Cognitive Neuroscience and Learning, Beijing Normal University, China\n');
    fprintf('The Nathan Kline Institute for Psychiatric Research, 140 Old Orangeburg Road, Orangeburg, NY 10962; Child Mind Institute, 445 Park Avenue, New York, NY 10022; The Phyllis Green and Randolph Cowen Institute for Pediatric Neuroscience, New York University Child Study Center, New York, NY 10016\n');
    fprintf('Mail to Author:  <a href="ycg.yan@gmail.com">YAN Chao-Gan</a>\nhttp://www.restfmri.net\n');
    fprintf('-----------------------------------------------------------\n');
    fprintf('Citing Information:\nIf you think DPARSFA is useful for your work, citing it in your paper would be greatly appreciated.\nSomething like "... The preprocessing was carried out by using Data Processing Assistant for Resting-State fMRI (DPARSF) (Yan & Zang, 2010, http://www.restfmri.net) which is based on Statistical Parametric Mapping (SPM8) (http://www.fil.ion.ucl.ac.uk/spm) and Resting-State fMRI Data Analysis Toolkit (REST, Song et al., 2011. http://www.restfmri.net)..."\nReference: Yan C and Zang Y (2010) DPARSF: a MATLAB toolbox for "pipeline" data analysis of resting-state fMRI. Front. Syst. Neurosci. 4:13. doi:10.3389/fnsys.2010.00013;     Song, X.W., Dong, Z.Y., Long, X.Y., Li, S.F., Zuo, X.N., Zhu, C.Z., He, Y., Yan, C.G., Zang, Y.F., 2011. REST: A Toolkit for Resting-State Functional Magnetic Resonance Imaging Data Processing. PLoS ONE 6, e25031.\n');
    
    handles.hContextMenu =uicontextmenu;
    set(handles.listSubjectID, 'UIContextMenu', handles.hContextMenu);	%Added by YAN Chao-Gan 091110. Added popup menu to delete selected subject by right click.
	uimenu(handles.hContextMenu, 'Label', 'Remove the selected participant', 'Callback', 'DPARSFA(''DeleteSelectedSubjectID'',gcbo,[], guidata(gcbo))');
    uimenu(handles.hContextMenu, 'Label', 'Remove all the participants', 'Callback', 'DPARSFA(''DeleteAllSubjects'',gcbo,[], guidata(gcbo))');

    handles.Cfg.WorkingDir =pwd;
    handles.Cfg.DataProcessDir =handles.Cfg.WorkingDir;
    handles.Cfg.SubjectID={};
    handles.Cfg.TimePoints=0;
    handles.Cfg.TR=2;
    handles.Cfg.IsNeedConvertFunDCM2IMG=1;
    handles.Cfg.IsNeedConvert4DFunInto3DImg=0;
    handles.Cfg.IsRemoveFirstTimePoints=1;
    handles.Cfg.RemoveFirstTimePoints=10;
    handles.Cfg.IsSliceTiming=1;
    handles.Cfg.SliceTiming.SliceNumber=33;
    handles.Cfg.SliceTiming.TR=handles.Cfg.TR;
    handles.Cfg.SliceTiming.TA=handles.Cfg.SliceTiming.TR-(handles.Cfg.SliceTiming.TR/handles.Cfg.SliceTiming.SliceNumber);
    handles.Cfg.SliceTiming.SliceOrder=[1:2:33,2:2:32];
    handles.Cfg.SliceTiming.ReferenceSlice=33;
    handles.Cfg.IsRealign=1;
    handles.Cfg.IsNeedReorientFunImgInteractively=1;
    
    handles.Cfg.IsNeedConvertT1DCM2IMG=1;
    handles.Cfg.IsNeedUnzipT1IntoT1Img=0;
    handles.Cfg.IsNeedReorientCropT1Img=0;
    handles.Cfg.IsNeedReorientT1ImgInteractively=1;
    handles.Cfg.IsNeedT1CoregisterToFun=1;
    handles.Cfg.IsNeedReorientInteractivelyAfterCoreg=0;
    
    handles.Cfg.IsSegment=2;
    handles.Cfg.Segment.AffineRegularisationInSegmentation='mni';
    
    handles.Cfg.IsDARTEL=1;
    
    handles.Cfg.IsNormalize=3; 
    handles.Cfg.Normalize.BoundingBox=[-90 -126 -72;90 90 108];
    handles.Cfg.Normalize.VoxSize=[3 3 3];
    handles.Cfg.IsDelFilesBeforeNormalize=0;
    handles.Cfg.IsSmooth=2;
    handles.Cfg.Smooth.FWHM=[4 4 4];
    
    handles.Cfg.IsDetrend=1; 
    handles.Cfg.IsFilter=1;
    handles.Cfg.Filter.ASamplePeriod=2;
    handles.Cfg.Filter.AHighPass_LowCutoff=0.01;
    handles.Cfg.Filter.ALowPass_HighCutoff=0.08;
    handles.Cfg.Filter.AMaskFilename='';
    handles.Cfg.Filter.AAddMeanBack='Yes';  %YAN Chao-Gan, 100420. %handles.Cfg.Filter.ARetrend='Yes';
    handles.Cfg.IsDelDetrendedFiles=0;
    
    handles.Cfg.MaskFile ='Default';
    handles.Cfg.IsCalReHo=0;
    handles.Cfg.CalReHo.ClusterNVoxel=27;
    handles.Cfg.CalReHo.AMaskFilename='Default';
    handles.Cfg.CalReHo.smReHo=1;
    handles.Cfg.CalReHo.mReHo_1=1;
    handles.Cfg.IsCalALFF=1;
    handles.Cfg.CalALFF.ASamplePeriod=2;
    handles.Cfg.CalALFF.AHighPass_LowCutoff=0.01;
    handles.Cfg.CalALFF.ALowPass_HighCutoff=0.08;
    handles.Cfg.CalALFF.AMaskFilename='Default';
    handles.Cfg.CalALFF.mALFF_1=1;
    handles.Cfg.IsCalfALFF=1;
    handles.Cfg.CalfALFF.ASamplePeriod=2;
    handles.Cfg.CalfALFF.AHighPass_LowCutoff=0.01;
    handles.Cfg.CalfALFF.ALowPass_HighCutoff=0.08;
    handles.Cfg.CalfALFF.AMaskFilename='Default';
    handles.Cfg.CalfALFF.mfALFF_1=1;
    handles.Cfg.IsCovremove=0;
    handles.Cfg.Covremove.HeadMotion=1;
    handles.Cfg.Covremove.WholeBrain=1;
    handles.Cfg.Covremove.CSF=1;
    handles.Cfg.Covremove.WhiteMatter=1;
    handles.Cfg.Covremove.OtherCovariatesROI=[]; %YAN Chao-Gan added 091215./091212.

    handles.Cfg.IsCalFC=0;
    handles.Cfg.IsExtractRESTdefinedROITC=0;
    handles.Cfg.CalFC.ROIDef=[];
    handles.Cfg.CalFC.AMaskFilename='Default';
    handles.Cfg.IsDefineROIInteractively = 0;

    handles.Cfg.IsExtractROITC=0;
    handles.Cfg.ExtractROITC.IsTalCoordinates=1;
    handles.Cfg.ExtractROITC.ROICenter='';%ROICenter;
    handles.Cfg.ExtractROITC.ROIRadius=6;
    
    handles.Cfg.IsExtractAALTC=0;
    handles.Cfg.IsWarpMasksIntoIndividualSpace=0;
    
    handles.Cfg.FunctionalSessionNumber=1; 
    handles.Cfg.StartingDirName='FunRaw';
    


    
    guidata(hObject, handles);
    UpdateDisplay(handles);
	movegui(handles.figDPARSFAMain, 'center');
	set(handles.figDPARSFAMain,'Name','DPARSFA');
    
    if ~(exist('rest.m')&&exist('spm.m'))
        uiwait(msgbox('DPARSFA is based on SPM and REST, Please install Matlab 7.3, SPM5, REST V1.3 or later version at first.','DPARSFA'));
    else
        [SPMversion,c]=spm('Ver');
        SPMversion=str2double(SPMversion(end));
        RESTversion=str2double(rest_misc('GETRESTVERSION'));
        FullMatlabVersion = sscanf(version,'%d.%d.%d.%d%s');
        if (SPMversion<5)||(RESTversion<1.3)||(FullMatlabVersion(1)*1000+FullMatlabVersion(2)<7*1000+3)
            uiwait(msgbox('DPARSFA is based on SPM and REST, Please install Matlab 7.3, SPM5, REST V1.3 or later version at first.','DPARSFA'));
        end
    end
	
    % Make Display correct in linux 
    if ~ispc
        ZoomFactor=0.8;  %ZoomFactor=0.85;
        ObjectNames = fieldnames(handles);
        for i=1:length(ObjectNames);
            eval(['IsFontSizeProp=isprop(handles.',ObjectNames{i},',''FontSize'');']);
            if IsFontSizeProp
                eval(['PCFontSize=get(handles.',ObjectNames{i},',''FontSize'');']);
                FontSize=PCFontSize*ZoomFactor;
                eval(['set(handles.',ObjectNames{i},',''FontSize'',',num2str(FontSize),');']);
            end
        end
    end
    
    
    % Choose default command line output for DPARSFA
    handles.output = hObject;	    
    guidata(hObject, handles);% Update handles structure

	% UIWAIT makes DPARSFA wait for user response (see UIRESUME)
	% uiwait(handles.figDPARSFAMain);

% --- Outputs from this function are returned to the command line.
function varargout = DPARSFA_OutputFcn(hObject, eventdata, handles) 
	% Get default command line output from handles structure
	varargout{1} = handles.output;

   
function edtWorkingDir_Callback(hObject, eventdata, handles)
	theDir =get(hObject, 'String');	
	SetWorkingDir(hObject,handles, theDir);

function btnSelectWorkingDir_Callback(hObject, eventdata, handles)
%     uiwait(msgbox({'DPARSF''s standard processing steps:';...
%         '1. Convert DICOM files to NIFTI images. 2. Remove First Time Points. 3. Slice Timing. 4. Realign. 5. Normalize. 6. Smooth (optional). 7. Detrend. 8. Filter. 9. Calculate ReHo, ALFF, fALFF (optional). 10. Regress out the Covariables (optional). 11. Calculate Functional Connectivity (optional). 12. Extract AAL or ROI time courses for further analysis (optional).';...
%         '';...
%         'All the input image files should be arranged in the working directory, and DPARSF will put all the output results in the working directory.';...
%         '';...
%         'For example, if you start with raw DICOM images, you need to arrange each subject''s fMRI DICOM images in one directory, and then put them in "FunRaw" directory under the working directory. i.e.:';...
%         '{Working Directory}\FunRaw\Subject001\xxxxx001.dcm';...
%         '{Working Directory}\FunRaw\Subject001\xxxxx002.dcm';...
%         '...';...
%         '{Working Directory}\FunRaw\Subject002\xxxxx001.dcm';...
%         '{Working Directory}\FunRaw\Subject002\xxxxx002.dcm';...
%         '...';...
%         '...';...
%         'Please do not name your subjects initiated with letter "a", DPARSF will face difficulties to distinguish the images before and after slice timing if the subjects'' name has an "a" initial.';...
%         '';...
%         'If you start with NIFTI images (.hdr/.img pairs) before slice timing, you need to arrange each subject''s fMRI NIFTI images in one directory, and then put them in "FunImg" directory under the working directory. i.e.:';...
%         '{Working Directory}\FunImg\Subject001\xxxxx001.img';...
%         '{Working Directory}\FunImg\Subject001\xxxxx002.img';...
%         '...';...
%         '{Working Directory}\FunImg\Subject002\xxxxx001.img';...
%         '{Working Directory}\FunImg\Subject002\xxxxx002.img';...
%         '...';...
%         '...';...
%         '';...
%         'If you start with NIFTI images after normalization, you need to arrange each subject''s NIFTI images in one directory, and then put them in "FunImgNormalized" directory under the working directory.';...
%         'If you start with NIFTI images after smooth, you need to arrange each subject''s NIFTI images in one directory, and then put them in "FunImgNormalizedSmoothed" directory under the working directory.';...
%         'If you start with NIFTI images after filter, you need to arrange each subject''s NIFTI images in one directory, and then put them in "FunImgNormalizedSmoothedDetrendedFiltered" (or "FunImgNormalizedDetrendedFiltered" if without smooth) directory under the working directory.';...
%         },'Please select the Working directory'));
	theDir =handles.Cfg.WorkingDir;
	theDir =uigetdir(theDir, 'Please select the Working directory: ');
	if ~isequal(theDir, 0)
		SetWorkingDir(hObject,handles, theDir);	
	end	
	
function SetWorkingDir(hObject, handles, ADir)
	if 7==exist(ADir,'dir')
		handles.Cfg.WorkingDir =ADir;
        handles.Cfg.DataProcessDir =handles.Cfg.WorkingDir;
		guidata(hObject, handles);
	    UpdateDisplay(handles);
    end
    handles=CheckCfgParameters(handles);
    guidata(hObject, handles);
    UpdateDisplay(handles);

function listSubjectID_Callback(hObject, eventdata, handles)
	theIndex =get(hObject, 'Value');

function listSubjectID_KeyPressFcn(hObject, eventdata, handles)
	%Delete the selected item when 'Del' is pressed
    key =get(handles.figDPARSFAMain, 'currentkey');
    if seqmatch({key},{'delete', 'backspace'})
       DeleteSelectedSubjectID(hObject, eventdata,handles);
    end   
	
function DeleteSelectedSubjectID(hObject, eventdata, handles)	
	theIndex =get(handles.listSubjectID, 'Value');
	if size(handles.Cfg.SubjectID, 1)==0 ...
		|| theIndex>size(handles.Cfg.SubjectID, 1),
		return;
	end
	theSubject     =handles.Cfg.SubjectID{theIndex, 1};
	tmpMsg=sprintf('Delete the Participant: "%s" ?', theSubject);
	if strcmp(questdlg(tmpMsg, 'Delete confirmation'), 'Yes')
		if theIndex>1,
			set(handles.listSubjectID, 'Value', theIndex-1);
		end
		handles.Cfg.SubjectID(theIndex, :)=[];
		if size(handles.Cfg.SubjectID, 1)==0
			handles.Cfg.SubjectID={};
		end	
		guidata(hObject, handles);
		UpdateDisplay(handles);
    end  

function DeleteAllSubjects(hObject, eventdata, handles)	
	tmpMsg=sprintf('Delete all the participants?');
	if strcmp(questdlg(tmpMsg, 'Delete confirmation'), 'Yes')
        handles.Cfg.SubjectID={};
		guidata(hObject, handles);
		UpdateDisplay(handles);
    end  
    
    
function ReLoadSubjects(hObject, eventdata, handles)	
    handles.Cfg.SubjectID={};
    handles=CheckCfgParameters(handles);
    guidata(hObject, handles);
    UpdateDisplay(handles);
    
function editTimePoints_Callback(hObject, eventdata, handles)
	handles.Cfg.TimePoints =str2double(get(hObject,'String'));
	guidata(hObject, handles);
    UpdateDisplay(handles);    
    
function editTR_Callback(hObject, eventdata, handles)
	handles.Cfg.TR =str2double(get(hObject,'String'));
    handles.Cfg.SliceTiming.TR=handles.Cfg.TR;
    handles.Cfg.SliceTiming.TA=handles.Cfg.SliceTiming.TR-(handles.Cfg.SliceTiming.TR/handles.Cfg.SliceTiming.SliceNumber);
    handles.Cfg.Filter.ASamplePeriod=handles.Cfg.TR;
    handles.Cfg.CalALFF.ASamplePeriod=handles.Cfg.TR;
    handles.Cfg.CalfALFF.ASamplePeriod=handles.Cfg.TR;
	guidata(hObject, handles);   
    UpdateDisplay(handles);    
    

function popupmenuTemplateParameters_Callback(hObject, eventdata, handles)
	[ProgramPath, fileN, extn] = fileparts(which('DPARSFA.m'));
    switch get(hObject, 'Value'),
        case 1,	%Template Parameters
            return;%Do nothing
        case 2, %Standard Steps: Normalized by DARTEL
            load([ProgramPath,filesep,'Jobmats',filesep,'Template_StandardSteps_ByDARTEL.mat']);
        case 3, %Standard Steps: Normalized by DARTEL (Start from .nii.gz files)
            load([ProgramPath,filesep,'Jobmats',filesep,'Template_StandardSteps_ByDARTEL_NiiGZData.mat']);
        case 4, %Standard Steps: Normalized by T1 image unified segmentation
            load([ProgramPath,filesep,'Jobmats',filesep,'Template_StandardSteps_ByT1UnifiedSegment.mat']);
        case 5, %Calculate in Original Space (Warp by information in unified segmentation)
            load([ProgramPath,filesep,'Jobmats',filesep,'Template_CalculateInOriginalSpace_Warp_UnifiedSegment.mat']);
        case 6, %Intraoperative Processing
            load([ProgramPath,filesep,'Jobmats',filesep,'Template_IntraoperativeProcessing.mat']);
        case 7, %VBM (New Segment and DARTEL)
            load([ProgramPath,filesep,'Jobmats',filesep,'Template_VBM_NewSegmentDARTEL.mat']);
        case 8, %VBM (unified segmentaition)
            load([ProgramPath,filesep,'Jobmats',filesep,'Template_VBM_UnifiedSegment.mat']);
        case 9, %Blank
            load([ProgramPath,filesep,'Jobmats',filesep,'Template_Blank.mat']);
    end

    Cfg.WorkingDir =pwd;
    Cfg.DataProcessDir =handles.Cfg.WorkingDir;
    SetLoadedData(hObject,handles, Cfg);
    
function ckboxEPIDICOM2NIFTI_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsNeedConvertFunDCM2IMG = 1;
        handles.Cfg.IsNeedConvert4DFunInto3DImg = 0;
	else	
		handles.Cfg.IsNeedConvertFunDCM2IMG = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);    

function checkboxConvert4DFunInto3DImg_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsNeedConvert4DFunInto3DImg = 1;
        handles.Cfg.IsNeedConvertFunDCM2IMG = 0;
	else	
		handles.Cfg.IsNeedConvert4DFunInto3DImg = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles); 
    
function checkboxRemoveFirstTimePoints_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsRemoveFirstTimePoints = 1;
	else	
		handles.Cfg.IsRemoveFirstTimePoints = 0;
    end	
    handles.Cfg.RemoveFirstTimePoints=handles.Cfg.RemoveFirstTimePoints*handles.Cfg.IsRemoveFirstTimePoints;
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);        
    
    
function editRemoveFirstTimePoints_Callback(hObject, eventdata, handles)
	handles.Cfg.RemoveFirstTimePoints =str2double(get(hObject,'String'));
    handles.Cfg.RemoveFirstTimePoints=handles.Cfg.RemoveFirstTimePoints*handles.Cfg.IsRemoveFirstTimePoints;
	guidata(hObject, handles);   
    UpdateDisplay(handles);      
    
function checkboxSliceTiming_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsSliceTiming = 1;
	else	
		handles.Cfg.IsSliceTiming = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles); 
    
function editSliceNumber_Callback(hObject, eventdata, handles)
	handles.Cfg.SliceTiming.SliceNumber =str2double(get(hObject,'String'));
    handles.Cfg.SliceTiming.TR = handles.Cfg.TR;
    handles.Cfg.SliceTiming.TA=handles.Cfg.SliceTiming.TR-(handles.Cfg.SliceTiming.TR/handles.Cfg.SliceTiming.SliceNumber);
	guidata(hObject, handles);   
    UpdateDisplay(handles);  
   
function editSliceOrder_Callback(hObject, eventdata, handles)
	SliceOrder=get(hObject,'String');
    handles.Cfg.SliceTiming.SliceOrder =eval(['[',SliceOrder,']']);
	guidata(hObject, handles);   
    UpdateDisplay(handles);    
   
function editReferenceSlice_Callback(hObject, eventdata, handles)
	handles.Cfg.SliceTiming.ReferenceSlice =str2double(get(hObject,'String'));
    guidata(hObject, handles);
    UpdateDisplay(handles); 
    
function checkboxRealign_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsRealign = 1;
	else	
		handles.Cfg.IsRealign = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);  

function checkboxReorientFunImgInteractively_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsNeedReorientFunImgInteractively = 1;
	else	
		handles.Cfg.IsNeedReorientFunImgInteractively = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);
    
function checkboxT1DICOM2NIFTI_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')

        uiwait(msgbox({'';...
            'If you want DPARSFA to convert the T1 DICOM images into NIFTI images, you need to arrange each subject''s T1 DICOM images in one directory, and then put them in "T1Raw" directory under the working directory. i.e.:';...
            '{Working Directory}\T1Raw\Subject001\xxxxx001.dcm';...
            '{Working Directory}\T1Raw\Subject001\xxxxx002.dcm';...
            '...';...
            '{Working Directory}\T1Raw\Subject002\xxxxx001.dcm';...
            '{Working Directory}\T1Raw\Subject002\xxxxx002.dcm';...
            '...';...
            '...';...
            },'Convert the T1 DICOM images into NIFTI'));

		handles.Cfg.IsNeedConvertT1DCM2IMG=1;
        handles.Cfg.IsNeedUnzipT1IntoT1Img=0;
        handles.Cfg.IsNeedReorientCropT1Img=0;
	else	
		handles.Cfg.IsNeedConvertT1DCM2IMG=0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);     
    
function checkboxUnzipT1intoT1Img_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
        
        uiwait(msgbox({'';...
            'If you want DPARSFA to unzip the T1 .nii.gz images, you need to arrange each subject''s T1 .nii.gz image in one directory, and then put them in "T1NiiGZ" directory under the working directory. i.e.:';...
            '{Working Directory}\T1NiiGZ\Subject001\xxxxx001.nii.gz';...
            '{Working Directory}\T1NiiGZ\Subject001\xxxxx002.nii.gz';...
            '...';...
            '{Working Directory}\T1NiiGZ\Subject002\xxxxx001.nii.gz';...
            '{Working Directory}\T1NiiGZ\Subject002\xxxxx002.nii.gz';...
            '...';...
            '...';...
            },'Unzip the T1 .nii.gz images'));
        
		handles.Cfg.IsNeedUnzipT1IntoT1Img=1;
        handles.Cfg.IsNeedReorientCropT1Img=1;
        handles.Cfg.IsNeedConvertT1DCM2IMG=0;
	else	
		handles.Cfg.IsNeedUnzipT1IntoT1Img=0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);  
    
function checkboxReorientCropT1Img_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
        
        uiwait(msgbox({'';...
            'If you want DPARSFA to crop the T1 .nii/.img images (Reorient to the nearest orthogonal direction to ''canonical space'' and remove excess air surrounding the individual as well as parts of the neck below the cerebellum, i.e., make co*.nii or co*.img), you need to arrange each subject''s T1 .nii/.img image in one directory, and then put them in "T1Img" directory under the working directory (if without previous steps). i.e.:';...
            '{Working Directory}\T1Img\Subject001\xxxxx001.nii';...
            '{Working Directory}\T1Img\Subject001\xxxxx002.nii';...
            '...';...
            '{Working Directory}\T1Img\Subject002\xxxxx001.nii';...
            '{Working Directory}\T1Img\Subject002\xxxxx002.nii';...
            '...';...
            '...';...
            },'Crop the T1 .nii/.img images'));
        
		handles.Cfg.IsNeedReorientCropT1Img=1;
        handles.Cfg.IsNeedConvertT1DCM2IMG=0;
	else	
		handles.Cfg.IsNeedReorientCropT1Img=0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);  
    
function checkboxReorientT1ImgInteractively_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
        
        uiwait(msgbox({'';...
            'If you want Re-orient T1 .nii/.img images Interactively (reorient to a good head position and click on the anterior commissure), you need to arrange each subject''s T1 .nii/.img image in one directory, and then put them in "T1Img" directory under the working directory (if without previous steps). i.e.:';...
            '{Working Directory}\T1Img\Subject001\xxxxx001.nii';...
            '{Working Directory}\T1Img\Subject001\xxxxx002.nii';...
            '...';...
            '{Working Directory}\T1Img\Subject002\xxxxx001.nii';...
            '{Working Directory}\T1Img\Subject002\xxxxx002.nii';...
            '...';...
            '...';...
            },'Re-orient T1 .nii/.img images Interactively'));
        
        
		handles.Cfg.IsNeedReorientT1ImgInteractively = 1;
	else	
		handles.Cfg.IsNeedReorientT1ImgInteractively = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);
    
function checkboxT1CoregisterToFun_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsNeedT1CoregisterToFun=1;
	else	
		handles.Cfg.IsNeedT1CoregisterToFun=0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);     
    
function checkboxReorientInteractivelyAfterCoreg_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsNeedReorientInteractivelyAfterCoreg=1;
	else	
		handles.Cfg.IsNeedReorientInteractivelyAfterCoreg=0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);     

function checkboxSegment_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsSegment=1;
        handles.Cfg.IsDARTEL=0;
	else	
		handles.Cfg.IsSegment=0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles); 
    
function checkboxNewSegment_DARTEL_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
        uiwait(msgbox({'';...
            'New Segment and DARTEL will be performed. You will have the segmentation results (c1*, c2*, c3*, ...) and DARTEL results (Template*, u_r*, wc1*, wc2*, mwc1*, mwc2*, smwc1*, smwc2*, ...) under {Working Directory}\T1ImgNewSegment';...
            '';...
            'Note: the wc*, mwc*, smwc* files (normalized into MNI space) are produced by DARTEL but not New Segment (want warped tissue) itself. smwc* files are smoothed by DARTEL with smooth kernel of [8 8 8]';...
            '';...
            },'New Segment + DARTEL'));
		handles.Cfg.IsSegment=2;
        handles.Cfg.IsDARTEL=1;
	else	
		handles.Cfg.IsSegment=0;
        handles.Cfg.IsDARTEL=0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles); 

function radiobuttonEastAsian_Callback(hObject, eventdata, handles)  %Added by YAN Chao-Gan 091110. Use different Affine Regularisation in Segmentation: East Asian brains (eastern) or European brains (mni).
    handles.Cfg.Segment.AffineRegularisationInSegmentation='eastern';
    set(handles.radiobuttonEastAsian,'Value',1);
	set(handles.radiobuttonEuropean,'Value',0);
    drawnow;    
	guidata(hObject, handles);   
    UpdateDisplay(handles);  
    
function radiobuttonEuropean_Callback(hObject, eventdata, handles)  %Added by YAN Chao-Gan 091110. Use different Affine Regularisation in Segmentation: East Asian brains (eastern) or European brains (mni).
    handles.Cfg.Segment.AffineRegularisationInSegmentation='mni';
    set(handles.radiobuttonEastAsian,'Value',0);
	set(handles.radiobuttonEuropean,'Value',1);
    drawnow;    
	guidata(hObject, handles);   
    UpdateDisplay(handles);        
  
function checkboxNormalize_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsNormalize = 1;
	else	
		handles.Cfg.IsNormalize = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);     

function editBoundingBox_Callback(hObject, eventdata, handles)
	BoundingBox=get(hObject,'String');
    handles.Cfg.Normalize.BoundingBox =eval(['[',BoundingBox,']']);
	guidata(hObject, handles);   
    UpdateDisplay(handles);    
   
function editVoxSize_Callback(hObject, eventdata, handles)
	VoxSize=get(hObject,'String');
    handles.Cfg.Normalize.VoxSize =eval(['[',VoxSize,']']);
	guidata(hObject, handles);   
    UpdateDisplay(handles);        
    
function radiobuttonNormalize_EPI_Callback(hObject, eventdata, handles)
    handles.Cfg.IsNormalize=1;
    drawnow;    
	guidata(hObject, handles);   
    UpdateDisplay(handles);  

function radiobuttonNormalize_T1_Callback(hObject, eventdata, handles)
    handles.Cfg.IsNormalize=2;
    drawnow;    
	guidata(hObject, handles);   
    UpdateDisplay(handles);  
    
function radiobuttonNormalize_DARTEL_Callback(hObject, eventdata, handles)
    handles.Cfg.IsNormalize=3;
    drawnow;    
	guidata(hObject, handles);   
    UpdateDisplay(handles);  
    
function checkboxIsDelFilesBeforeNormalize_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsDelFilesBeforeNormalize=1;
	else	
		handles.Cfg.IsDelFilesBeforeNormalize=0;
    end	
	guidata(hObject, handles);
	UpdateDisplay(handles);      
    
function checkboxSmooth_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsSmooth = 1;
	else	
		handles.Cfg.IsSmooth = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);     
    
function checkboxSmoothByDARTEL_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsSmooth = 2;
	else	
		handles.Cfg.IsSmooth = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);  
    
function editFWHM_Callback(hObject, eventdata, handles)
	FWHM=get(hObject,'String');
    handles.Cfg.Smooth.FWHM =eval(['[',FWHM,']']);
	guidata(hObject, handles);   
    UpdateDisplay(handles);      
 
function checkboxDetrend_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsDetrend = 1;
	else	
		handles.Cfg.IsDetrend = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);       

function ckboxFilter_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsFilter = 1;
	else	
		handles.Cfg.IsFilter = 0;
        handles.Cfg.IsDelDetrendedFiles = 0;
    end	
    handles.Cfg.Filter.ASamplePeriod=handles.Cfg.TR;
    handles.Cfg.Filter.AMaskFilename='';
    handles.Cfg.Filter.AAddMeanBack='Yes'; %YAN Chao-Gan, 100420. %handles.Cfg.Filter.ARetrend='Yes';
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);

function edtBandLow_Callback(hObject, eventdata, handles)
	handles.Cfg.Filter.AHighPass_LowCutoff =str2double(get(hObject,'String'));
	guidata(hObject, handles);
    UpdateDisplay(handles);

function edtBandHigh_Callback(hObject, eventdata, handles)
	handles.Cfg.Filter.ALowPass_HighCutoff =str2double(get(hObject,'String'));
	guidata(hObject, handles);
    UpdateDisplay(handles);
   
function checkboxIsDelDetrendedFiles_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsDelDetrendedFiles = 1;
        uiwait(msgbox({'If you want to calculate fALFF, please do not delete detrended files.';...
            },'Delete detrended files'));
	else	
		handles.Cfg.IsDelDetrendedFiles = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);    
    
    
function edtMaskfile_Callback(hObject, eventdata, handles)
	theMaskfile =get(hObject, 'String');
    theMaskfile =strtrim(theMaskfile);
	if exist(theMaskfile, 'file')
		handles.Cfg.MaskFile =theMaskfile;
		guidata(hObject, handles);
	else
		errordlg(sprintf('The mask file "%s" does not exist!\n Please re-check it.', theMaskfile));
    end
    handles.Cfg.CalReHo.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalfALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalFC.AMaskFilename=handles.Cfg.MaskFile;
    guidata(hObject, handles);

function btnSelectMask_Callback(hObject, eventdata, handles)
	[filename, pathname] = uigetfile({'*.img;*.mat', 'All Mask files (*.img; *.mat)'; ...
												'*.mat','MAT masks (*.mat)'; ...
												'*.img', 'ANALYZE or NIFTI masks(*.img)'}, ...
												'Pick a user''s  mask');
    if ~(filename==0)
        handles.Cfg.MaskFile =[pathname filename];
        guidata(hObject,handles);
    elseif ~( exist(handles.Cfg.MaskFile, 'file')==2)
        set(handles.rbtnDefaultMask, 'Value',[1]);        
        set(handles.rbtnUserMask, 'Value',[0]); 
        set(handles.rbtnNullMask, 'Value',[0]); 
		set(handles.edtMaskfile, 'Enable','off');
		set(handles.btnSelectMask, 'Enable','off');			
		handles.Cfg.MaskFile ='Default';
		guidata(hObject, handles);        
    end    
    handles.Cfg.CalReHo.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalfALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalFC.AMaskFilename=handles.Cfg.MaskFile;
    guidata(hObject, handles);
    UpdateDisplay(handles);

function rbtnDefaultMask_Callback(hObject, eventdata, handles)
	set(handles.edtMaskfile, 'Enable','off', 'String','Use Default Mask');
	set(handles.btnSelectMask, 'Enable','off');	
	drawnow;
    handles.Cfg.MaskFile ='Default';
    handles.Cfg.CalReHo.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalfALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalFC.AMaskFilename=handles.Cfg.MaskFile;
	guidata(hObject, handles);
    set(handles.rbtnDefaultMask,'Value',1);
	set(handles.rbtnNullMask,'Value',0);
	set(handles.rbtnUserMask,'Value',0);

function rbtnUserMask_Callback(hObject, eventdata, handles)
	set(handles.edtMaskfile,'Enable','on', 'String',handles.Cfg.MaskFile);
	set(handles.btnSelectMask, 'Enable','on');
	set(handles.rbtnDefaultMask,'Value',0);
	set(handles.rbtnNullMask,'Value',0);
	set(handles.rbtnUserMask,'Value',1);
    drawnow;
	
function rbtnNullMask_Callback(hObject, eventdata, handles)
	set(handles.edtMaskfile, 'Enable','off', 'String','Don''t use any Mask');
	set(handles.btnSelectMask, 'Enable','off');
	drawnow;
	handles.Cfg.MaskFile ='';
    handles.Cfg.CalReHo.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalfALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles.Cfg.CalFC.AMaskFilename=handles.Cfg.MaskFile;
	guidata(hObject, handles);
    set(handles.rbtnDefaultMask,'Value',0);
	set(handles.rbtnNullMask,'Value',1);
	set(handles.rbtnUserMask,'Value',0);    
    
function checkboxCalReHo_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsCalReHo = 1;
	else	
		handles.Cfg.IsCalReHo = 0;
    end	
    handles.Cfg.CalReHo.AMaskFilename=handles.Cfg.MaskFile;
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);    
    
function radiobuttonReHo7voxels_Callback(hObject, eventdata, handles)
    handles.Cfg.CalReHo.ClusterNVoxel = 7;
    set(handles.radiobuttonReHo7voxels,'Value',1);
	set(handles.radiobuttonReHo19voxels,'Value',0);
	set(handles.radiobuttonReHo27voxels,'Value',0);
    guidata(hObject, handles);
	UpdateDisplay(handles); 

function radiobuttonReHo19voxels_Callback(hObject, eventdata, handles)
    handles.Cfg.CalReHo.ClusterNVoxel = 19;
    set(handles.radiobuttonReHo7voxels,'Value',0);
	set(handles.radiobuttonReHo19voxels,'Value',1);
	set(handles.radiobuttonReHo27voxels,'Value',0);
    guidata(hObject, handles);
	UpdateDisplay(handles); 
	
function radiobuttonReHo27voxels_Callback(hObject, eventdata, handles)
    handles.Cfg.CalReHo.ClusterNVoxel = 27;
    set(handles.radiobuttonReHo7voxels,'Value',0);
	set(handles.radiobuttonReHo19voxels,'Value',0);
	set(handles.radiobuttonReHo27voxels,'Value',1);
    guidata(hObject, handles);
	UpdateDisplay(handles); 

function checkboxsmReHo_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.CalReHo.smReHo = 1;
        uiwait(msgbox({['Smooth the mReHo results: the smooth kernel is the same as the kernel set in "Smooth FWHM" part, that is: ',mat2str(handles.Cfg.Smooth.FWHM)];...
            },'ReHo'));
	else	
		handles.Cfg.CalReHo.smReHo = 0;
    end	
	guidata(hObject, handles);
	UpdateDisplay(handles);    
    
function checkboxmReHo_1_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.CalReHo.mReHo_1 = 1;
	else	
		handles.Cfg.CalReHo.mReHo_1 = 0;
    end	
    uiwait(msgbox({'One-sample t test on ReHo results usually want to see regions shown significantly higher ReHo than the global mean ReHo of the whole brain, thus we compare mReHo results with base "1". Since one-sample t test module in SPM just can compare values with base "0", we need to subtract "1" from the mReHo results, then perform one-sample t test on the subtracted mReHo in SPM.';...
            },'ReHo'));
	guidata(hObject, handles);
	UpdateDisplay(handles);        
    
function checkboxCalALFF_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsCalALFF = 1;
	else	
		handles.Cfg.IsCalALFF = 0;
    end	
    handles.Cfg.CalALFF.ASamplePeriod=handles.Cfg.TR;
    handles.Cfg.CalALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);        
    
function checkboxCalfALFF_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsCalfALFF = 1;
%         uiwait(msgbox({'fALFF calculation is based on data before filter, i.e., detrended data.';...
%             },'fALFF'));
	else	
		handles.Cfg.IsCalfALFF = 0;
    end	
    handles.Cfg.CalfALFF.ASamplePeriod=handles.Cfg.TR;
    handles.Cfg.CalfALFF.AMaskFilename=handles.Cfg.MaskFile;
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);      

function edtfAlffBandLow_Callback(hObject, eventdata, handles)
	handles.Cfg.CalALFF.AHighPass_LowCutoff =str2double(get(hObject,'String'));
    handles.Cfg.CalfALFF.AHighPass_LowCutoff=handles.Cfg.CalALFF.AHighPass_LowCutoff;
	guidata(hObject, handles);

function edtfAlffBandHigh_Callback(hObject, eventdata, handles)
	handles.Cfg.CalALFF.ALowPass_HighCutoff =str2double(get(hObject,'String'));
    handles.Cfg.CalfALFF.ALowPass_HighCutoff=handles.Cfg.CalALFF.ALowPass_HighCutoff;
	guidata(hObject, handles);
 
function checkboxmALFF_1_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.CalALFF.mALFF_1 = 1;
        handles.Cfg.CalfALFF.mfALFF_1 = 1;
	else	
		handles.Cfg.CalALFF.mALFF_1 = 0;
        handles.Cfg.CalfALFF.mfALFF_1 = 0;
    end	
	guidata(hObject, handles);
	UpdateDisplay(handles);      
    
function checkboxCovremove_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsCovremove = 1;
        uiwait(msgbox({'Linear regression was performed to remove the effects of the nuisance covariates:';...
            '1. Six head motion parameters: estimated by SPM5''s realign step. If you do not want to use SPM5'' realign, please arrange each subject''s rp*.txt file in one directory (named as same as its functional image directory) , and then put them in "RealignParameter" directory under the working directory. i.e.:';...
            '{Working Directory}\RealignParameter\Subject001\rpxxxxx.txt';...
            '...';...
            '{Working Directory}\RealignParameter\Subject002\rpxxxxx.txt';...
            '...';...
            '2. Global mean signal: mask created by setting a threshold at 50% on SPM5''s apriori mask (brainmask.nii).';...
            '3. White matter signal: mask created by setting a threshold at 90% on SPM5''s apriori mask (white.nii).';...
            '4. Cerebrospinal fluid signal: mask created by setting a threshold at 70% on SPM5''s apriori mask (csf.nii).';...
            '';...
            %         'The regression was based on data after filter, if you want to regress another kind of data, please arrange each subject''s NIFTI images in one directory, and then put them in "FunImgNormalizedSmoothedDetrendedFiltered" (or "FunImgNormalizedDetrendedFiltered") directory under the working directory. i.e.:';...
            %         '{Working Directory}\FunImgNormalizedSmoothedDetrendedFiltered\Subject001\xxx001.img';...
            %         '{Working Directory}\FunImgNormalizedSmoothedDetrendedFiltered\Subject001\xxx002.img';...
            %         '...';...
            %         '{Working Directory}\FunImgNormalizedSmoothedDetrendedFiltered\Subject002\xxx001.img';...
            %         '{Working Directory}\FunImgNormalizedSmoothedDetrendedFiltered\Subject002\xxx002.img';...
            %         '...';...
            '';...
            },'Regress out nuisance covariates:'));
	else	
		handles.Cfg.IsCovremove = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);     
    
function checkboxCovremoveHeadMotion_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.Covremove.HeadMotion = 1;
	else	
		handles.Cfg.Covremove.HeadMotion = 0;
    end	
	guidata(hObject, handles);
	UpdateDisplay(handles); 
    
function checkboxCovremoveWholeBrain_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.Covremove.WholeBrain = 1;
	else	
		handles.Cfg.Covremove.WholeBrain = 0;
    end	
	guidata(hObject, handles);
	UpdateDisplay(handles);    
    
function checkboxCovremoveWhiteMatter_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.Covremove.WhiteMatter = 1;
	else	
		handles.Cfg.Covremove.WhiteMatter = 0;
    end	
	guidata(hObject, handles);
	UpdateDisplay(handles); 
    
function checkboxCovremoveCSF_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.Covremove.CSF = 1;
	else	
		handles.Cfg.Covremove.CSF = 0;
    end	
	guidata(hObject, handles);
	UpdateDisplay(handles);     
    
function checkboxOtherCovariates_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
        ROIDef=handles.Cfg.Covremove.OtherCovariatesROI;
        ROIDef=rest_ROIList_gui(ROIDef);
        handles.Cfg.Covremove.OtherCovariatesROI=ROIDef;
	else	
		handles.Cfg.Covremove.OtherCovariatesROI=[];
    end	
	guidata(hObject, handles);
	UpdateDisplay(handles);      

function checkboxCalFC_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsCalFC = 1;
	else	
		handles.Cfg.IsCalFC = 0;
    end	
    handles.Cfg.CalFC.AMaskFilename=handles.Cfg.MaskFile;
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);   
    
function checkboxExtractRESTdefinedROITC_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsExtractRESTdefinedROITC = 1;
	else	
		handles.Cfg.IsExtractRESTdefinedROITC = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);        
 
 function pushbuttonDefineROI_Callback(hObject, eventdata, handles)
    ROIDef=handles.Cfg.CalFC.ROIDef;
    ROIDef=rest_ROIList_gui(ROIDef);
    handles.Cfg.CalFC.ROIDef=ROIDef;
    guidata(hObject, handles);
	UpdateDisplay(handles); 

function checkboxDefineROIInteractively_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsDefineROIInteractively = 1;
	else	
		handles.Cfg.IsDefineROIInteractively = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);    
    
function checkboxExtractAALTC_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
		handles.Cfg.IsExtractAALTC = 1;
	else	
		handles.Cfg.IsExtractAALTC = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);    
    
    
function checkboxWarpMasksIntoIndividualSpace_Callback(hObject, eventdata, handles)
	if get(hObject,'Value')
        
        
        uiwait(msgbox({'If this option is checked, all the masks will be warped to the individual space by using the "*_seg_inv_sn.mat" stored in "T1ImgSegment" directory which is estimated in the T1 image unified segmentation.';...
            'The following masks will be warped:';...
            '1. The calculation mask (also regarded as the whole-brain mask, e.g. the "Default mask") in ReHo, ALFF/fALFF and Functional Connectivity analysis.';...
            '2. The covariates masks in regressing out covariates: Global mask (50% threshold on SPM5''s brainmask.nii), White matter mask (90% threshold on SPM5''s white.nii) and Cerebrospinal fluid mask (70% threshold on SPM5''s csf.nii).';...
            '3. The ROI masks used in Functional Connectivity or Extracting ROI Time courses.';...
            '4. The AAL mask used in Extracting AAL time courses (90 regions)';...
            'Note: At the current stage, this function is not supported if you choose New Segment and DARTEL option.';...
            },'Tips for Warp Masks into Individual Space'));
        
        
        
		handles.Cfg.IsWarpMasksIntoIndividualSpace = 1;
	else	
		handles.Cfg.IsWarpMasksIntoIndividualSpace = 0;
    end	
    handles=CheckCfgParameters(handles);
	guidata(hObject, handles);
	UpdateDisplay(handles);    
    
function editFunctionalSessionNumber_Callback(hObject, eventdata, handles)
    uiwait(msgbox({'If you have mutilple functional sessions, you need to specify the number of sessions.';...
        'And your directory should be named as FunRaw (or FunImg) for the first session';...
        'S2_FunRaw (or S2_FunImg) for the second session.';...
        'S3_FunRaw (or S3_FunImg) for the third session';...
        '...';...
        },'Tips for Multiple Functional Sessions'));
    
    handles.Cfg.FunctionalSessionNumber =str2double(get(hObject,'String'));
    handles=CheckCfgParameters(handles);
    guidata(hObject, handles);
    UpdateDisplay(handles);
    
    
    
function editStartingDirName_Callback(hObject, eventdata, handles)
    uiwait(msgbox({'If you do not start with raw DICOM images, you need to specify the Starting Directory Name.';...
        'E.g. "FunImgARW" means you start with images which have been slice timed, realigned and normalized.';...
        '';...
        'Abbreviations:';...
        'A - Slice Timing;';...
        'R - Realign';...
        'W - Normalize';...
        'S - Smooth';...
        'D - Detrend';...
        'F - Filter';...
        'C - Covariates Removed';...
        },'Tips for Starting Directory Name'));

    handles.Cfg.StartingDirName=get(hObject,'String');
    handles=CheckCfgParametersBeforeRun(handles);
    guidata(hObject, handles);
    UpdateDisplay(handles);
    
    
function pushbuttonHelp_Callback(hObject, eventdata, handles)
	web('http://www.restfmri.net');    
    
function pushbuttonSave_Callback(hObject, eventdata, handles)
	[filename, pathname] = uiputfile({'*.mat'}, 'Save Parameters As');
    Cfg=handles.Cfg;
    save(['',pathname,filename,''], 'Cfg');
    
function handles=pushbuttonLoad_Callback(hObject, eventdata, handles)
	[filename, pathname] = uigetfile({'*.mat'}, 'Load Parameters From');
    load([pathname,filename]);
    SetLoadedData(hObject,handles, Cfg);	

function SetLoadedData(hObject,handles, Cfg);	
    handles.Cfg=Cfg;

    if ~isfield(handles.Cfg,'FunctionalSessionNumber')
        handles.Cfg.FunctionalSessionNumber=1;
    end
    if ~isfield(handles.Cfg,'IsNeedConvert4DFunInto3DImg')
        handles.Cfg.IsNeedConvert4DFunInto3DImg=0;
    end
    if ~isfield(handles.Cfg,'IsNeedReorientFunImgInteractively')
        handles.Cfg.IsNeedReorientFunImgInteractively=0;
    end
    if ~isfield(handles.Cfg,'IsNeedUnzipT1IntoT1Img')
        handles.Cfg.IsNeedUnzipT1IntoT1Img=0;
    end
    if ~isfield(handles.Cfg,'IsNeedReorientCropT1Img')
        handles.Cfg.IsNeedReorientCropT1Img=0;
    end
    if ~isfield(handles.Cfg,'IsNeedReorientT1ImgInteractively')
        handles.Cfg.IsNeedReorientT1ImgInteractively=0;
    end
    if isfield(handles.Cfg,'IsNeedReorientInteractively')
        handles.Cfg.IsNeedReorientInteractivelyAfterCoreg = handles.Cfg.IsNeedReorientInteractively;
    end
    if ~isfield(handles.Cfg,'IsDARTEL')
        handles.Cfg.IsDARTEL=0;
    end

    guidata(hObject, handles);
    UpdateDisplay(handles);
    
function pushbuttonUtilities_Callback(hObject, eventdata, handles)
    [ProgramPath, fileN, extn] = fileparts(which('DPARSFA.m'));
    addpath([ProgramPath,filesep,'SubGUIs']);
	Utilities_fig=figure('name','Utilities','menubar','none','numbertitle','off','position',[100 100 300 100]);
    uicontrol(Utilities_fig,'Style','pushbutton', 'Position',[50 30 200 40],...
        'String','Change the Prefix of Images','ToolTipString','Change the Prefix of Images since DPARSF need some special prefixes in some cases.', ...
        'Callback', 'DPARSF_ChangeImgPrefix_gui')
    movegui(Utilities_fig, 'center');

    
function pushbuttonQuit_Callback(hObject, eventdata, handles)
	close(handles.figDPARSFAMain);     
    
function pushbuttonRun_Callback(hObject, eventdata, handles)
    [handles, CheckingPass]=CheckCfgParametersBeforeRun(handles);
    if CheckingPass==0
        return
    end
    
    RawBackgroundColor=get(handles.pushbuttonRun ,'BackgroundColor');
    RawForegroundColor=get(handles.pushbuttonRun ,'ForegroundColor');
    set(handles.pushbuttonRun ,'Enable', 'off','BackgroundColor', 'red','ForegroundColor','green');
    Cfg=handles.Cfg; %Added by YAN Chao-Gan, 100130. Save the configuration parameters automatically.
    Datetime=fix(clock); %Added by YAN Chao-Gan, 100130.
    save([handles.Cfg.DataProcessDir,filesep,'DPARSFA_AutoSave_',num2str(Datetime(1)),'_',num2str(Datetime(2)),'_',num2str(Datetime(3)),'_',num2str(Datetime(4)),'_',num2str(Datetime(5)),'.mat'], 'Cfg'); %Added by YAN Chao-Gan, 100130.
    [Error]=DPARSFA_run(handles.Cfg);
    if ~isempty(Error)
        uiwait(msgbox(Error,'Errors were encountered while processing','error'));
    end
    set(handles.pushbuttonRun ,'Enable', 'on','BackgroundColor', RawBackgroundColor,'ForegroundColor',RawForegroundColor);	
 	UpdateDisplay(handles);     
    
%% Check if the configuration parameters is correct
function [handles, CheckingPass]=CheckCfgParameters(handles)   %The parameter checking is no longer needed every time 
    CheckingPass=1;
    return
    
    
%% Check if the configuration parameters is correct
function [handles, CheckingPass]=CheckCfgParametersBeforeRun(handles)    
    CheckingPass=0;
    if isempty (handles.Cfg.WorkingDir)
        uiwait(msgbox('Please set the working directory!','Configuration parameters checking','warn'));
        return
    end
    
    if (handles.Cfg.IsNeedConvertFunDCM2IMG==1)
        handles.Cfg.StartingDirName='FunRaw';
        if 7==exist([handles.Cfg.WorkingDir,filesep,'FunRaw'],'dir')
            if isempty (handles.Cfg.SubjectID)
                Dir=dir([handles.Cfg.WorkingDir,filesep,'FunRaw']);
                if strcmpi(Dir(3).name,'.DS_Store')  %110908 YAN Chao-Gan, for MAC OS compatablie
                    StartIndex=4;
                else
                    StartIndex=3;
                end
                for i=StartIndex:length(Dir)
                    handles.Cfg.SubjectID=[handles.Cfg.SubjectID;{Dir(i).name}];
                end
            end
        else
            uiwait(msgbox('Please arrange each subject''s DICOM images in one directory, and then put them in "FunRaw" directory under the working directory!','Configuration parameters checking','warn'));
            return
        end
    else
        if 7==exist([handles.Cfg.WorkingDir,filesep,handles.Cfg.StartingDirName],'dir')
            if isempty (handles.Cfg.SubjectID)
                Dir=dir([handles.Cfg.WorkingDir,filesep,handles.Cfg.StartingDirName]);
                if strcmpi(Dir(3).name,'.DS_Store')  %110908 YAN Chao-Gan, for MAC OS compatablie
                    StartIndex=4;
                else
                    StartIndex=3;
                end
                for i=StartIndex:length(Dir)
                    handles.Cfg.SubjectID=[handles.Cfg.SubjectID;{Dir(i).name}];
                end
            end
            
            if ~(strcmpi(handles.Cfg.StartingDirName,'T1Raw') || strcmpi(handles.Cfg.StartingDirName,'T1Img') || strcmpi(handles.Cfg.StartingDirName,'T1NiiGZ') || (handles.Cfg.IsNeedConvert4DFunInto3DImg==1) ) %If not just use for VBM, check if the time points right. %YAN Chao-Gan, 111130. Also add T1 .nii.gz support.
                DirImg=dir([handles.Cfg.WorkingDir,filesep,handles.Cfg.StartingDirName,filesep,handles.Cfg.SubjectID{1},filesep,'*.img']);
                if isempty(DirImg)  %YAN Chao-Gan, 111114. Also support .nii files.
                    DirImg=dir([handles.Cfg.WorkingDir,filesep,handles.Cfg.StartingDirName,filesep,handles.Cfg.SubjectID{1},filesep,'*.nii']);
                end
                if length(DirImg)~=(handles.Cfg.TimePoints) %YAN Chao-Gan 090922, %if length(DirImg)~=(handles.Cfg.TimePoints-handles.Cfg.RemoveFirstTimePoints)
                    uiwait(msgbox(['The detected time points of subject "',handles.Cfg.SubjectID{1},'" is: ',num2str(length(DirImg)),', it is different from the predefined time points: ',num2str(handles.Cfg.TimePoints),'. Please check your data!'],'Configuration parameters checking','warn')); %YAN Chao-Gan 090922, %uiwait(msgbox(['The detected time points of subject "',handles.Cfg.SubjectID{1},'" is: ',num2str(length(DirImg)),', it is different from the predefined time points: ',num2str(handles.Cfg.TimePoints-handles.Cfg.RemoveFirstTimePoints),'. Please check your data!'],'Configuration parameters checking','warn'));
                    return
                end
            end
        else
            uiwait(msgbox(['Please arrange each subject''s NIFTI images in one directory, and then put them in your defined Starting Directory Name "',handles.Cfg.StartingDirName,'" directory under the working directory!'],'Configuration parameters checking','warn'));
            return
        end
    end %handles.Cfg.IsNeedConvertT1DCM2IMG
    
    if handles.Cfg.TimePoints==0
        uiwait(msgbox('Please set the number of time points of your functional MRI data!','Configuration parameters checking','warn'));
        return
    end
    
    if (handles.Cfg.IsSliceTiming==1) && (length(handles.Cfg.SliceTiming.SliceOrder)==length([1:2:33,2:2:32]))
        if all(handles.Cfg.SliceTiming.SliceOrder==[1:2:33,2:2:32])
            %uiwait(msgbox('Please ensure the default Slice Timing parameters (Slice Number, Order, Reference Slice) are suitable for your data.','Configuration parameters checking'));
            %Revised by YAN Chao-Gan, 100130.
            Answer=questdlg('Are you sure the default Slice Timing parameters (Slice Number, Order, Reference Slice) are suitable for your data?','Configuration parameters checking','Yes','No','No');
            if ~strcmpi(Answer,'Yes')
                return
            end
        end
    end
    
    %Added by YAN Chao-Gan, 100130.
    if (handles.Cfg.IsSmooth==1) && (handles.Cfg.IsCalReHo==1)
        Answer=questdlg('Smoothing is usually performed after ReHo Calculation. Are you sure to calculate ReHo based on smoothed data?','Configuration parameters checking','Yes','No','No');
        if ~strcmpi(Answer,'Yes')
            return
        end
    end
    
    CheckingPass=1;
    UpdateDisplay(handles);
        
    
    
%% Update All the uiControls' display on the GUI
function UpdateDisplay(handles)
	set(handles.edtWorkingDir ,'String', handles.Cfg.WorkingDir);	
    
    if size(handles.Cfg.SubjectID,1)>0
		theOldIndex =get(handles.listSubjectID, 'Value');
		set(handles.listSubjectID, 'String',  handles.Cfg.SubjectID , 'Value', 1);
		theCount =size(handles.Cfg.SubjectID,1);
		if (theOldIndex>0) && (theOldIndex<= theCount)
			set(handles.listSubjectID, 'Value', theOldIndex);
		end
	else
		set(handles.listSubjectID, 'String', '' , 'Value', 0);
    end
    
    set(handles.editTimePoints ,'String', num2str(handles.Cfg.TimePoints));	
    set(handles.editTR ,'String', num2str(handles.Cfg.TR));	
    set(handles.ckboxEPIDICOM2NIFTI, 'Value', handles.Cfg.IsNeedConvertFunDCM2IMG);
    set(handles.checkboxConvert4DFunInto3DImg, 'Value', handles.Cfg.IsNeedConvert4DFunInto3DImg);
    % set(handles.editRemoveFirstTimePoints ,'String', num2str(handles.Cfg.RemoveFirstTimePoints));
    % Revised by YAN Chao-Gan 091110. Add a checkbox to avoid forgeting to check this parameter.
    if handles.Cfg.IsRemoveFirstTimePoints==1
        set(handles.checkboxRemoveFirstTimePoints, 'Value', 1);	
        set(handles.editRemoveFirstTimePoints, 'Enable', 'on', 'String', num2str(handles.Cfg.RemoveFirstTimePoints));
    else
        set(handles.checkboxRemoveFirstTimePoints, 'Value', 0);	
        set(handles.editRemoveFirstTimePoints, 'Enable', 'off', 'String', num2str(handles.Cfg.RemoveFirstTimePoints));
    end
    
    if handles.Cfg.IsSliceTiming==1
		set(handles.checkboxSliceTiming, 'Value', 1);	
        set(handles.editSliceNumber, 'Enable', 'on', 'String', num2str(handles.Cfg.SliceTiming.SliceNumber));
        set(handles.editSliceOrder, 'Enable', 'on', 'String', mat2str(handles.Cfg.SliceTiming.SliceOrder));
        set(handles.editReferenceSlice, 'Enable', 'on', 'String', num2str(handles.Cfg.SliceTiming.ReferenceSlice));
        set(handles.textSliceNumber,'Enable', 'on');
        set(handles.textSliceOrder,'Enable', 'on');
        set(handles.textReferenceSlice,'Enable', 'on');
    else
        set(handles.checkboxSliceTiming, 'Value', 0);	
        set(handles.editSliceNumber, 'Enable', 'off', 'String', num2str(handles.Cfg.SliceTiming.SliceNumber));
        set(handles.editSliceOrder, 'Enable', 'off', 'String', mat2str(handles.Cfg.SliceTiming.SliceOrder));
        set(handles.editReferenceSlice, 'Enable', 'off', 'String', num2str(handles.Cfg.SliceTiming.ReferenceSlice));
        set(handles.textSliceNumber,'Enable', 'off');
        set(handles.textSliceOrder,'Enable', 'off');
        set(handles.textReferenceSlice,'Enable', 'off');
    end
    
    set(handles.checkboxRealign, 'Value', handles.Cfg.IsRealign);
    set(handles.checkboxReorientFunImgInteractively, 'Value', handles.Cfg.IsNeedReorientFunImgInteractively);
    set(handles.checkboxT1DICOM2NIFTI, 'Value', handles.Cfg.IsNeedConvertT1DCM2IMG);
    set(handles.checkboxUnzipT1intoT1Img, 'Value', handles.Cfg.IsNeedUnzipT1IntoT1Img);
    set(handles.checkboxReorientCropT1Img, 'Value', handles.Cfg.IsNeedReorientCropT1Img);
    set(handles.checkboxReorientT1ImgInteractively, 'Value', handles.Cfg.IsNeedReorientT1ImgInteractively);
    set(handles.checkboxT1CoregisterToFun, 'Value', handles.Cfg.IsNeedT1CoregisterToFun);
    set(handles.checkboxReorientInteractivelyAfterCoreg, 'Value', handles.Cfg.IsNeedReorientInteractivelyAfterCoreg);

    set(handles.checkboxSegment, 'Value', handles.Cfg.IsSegment == 1);
    set(handles.checkboxNewSegment_DARTEL, 'Value', handles.Cfg.IsSegment == 2);
    if handles.Cfg.IsSegment>0
        set(handles.textAffineRegularisation, 'Visible', 'on');
        set(handles.radiobuttonEastAsian,'Visible', 'on','Value',strcmpi(handles.Cfg.Segment.AffineRegularisationInSegmentation,'eastern'));
        set(handles.radiobuttonEuropean,'Visible', 'on','Value',strcmpi(handles.Cfg.Segment.AffineRegularisationInSegmentation,'mni'));
    else
        set(handles.textAffineRegularisation, 'Visible', 'off');
        set(handles.radiobuttonEastAsian,'Visible', 'off','Value',strcmpi(handles.Cfg.Segment.AffineRegularisationInSegmentation,'eastern'));
        set(handles.radiobuttonEuropean,'Visible', 'off','Value',strcmpi(handles.Cfg.Segment.AffineRegularisationInSegmentation,'mni'));
    end
    
    if handles.Cfg.IsNormalize>0
		set(handles.checkboxNormalize, 'Value', 1);	
        set(handles.editBoundingBox, 'Enable', 'on', 'String', mat2str(handles.Cfg.Normalize.BoundingBox));
        set(handles.editVoxSize, 'Enable', 'on', 'String', mat2str(handles.Cfg.Normalize.VoxSize));
        set(handles.radiobuttonNormalize_EPI,'Enable', 'on', 'Value',handles.Cfg.IsNormalize==1);
        set(handles.radiobuttonNormalize_T1,'Enable', 'on', 'Value',handles.Cfg.IsNormalize==2);
        set(handles.radiobuttonNormalize_DARTEL,'Enable', 'on', 'Value',handles.Cfg.IsNormalize==3);
        set(handles.checkboxIsDelFilesBeforeNormalize,'Enable', 'on', 'Value',handles.Cfg.IsDelFilesBeforeNormalize);
        set(handles.textBoundingBox,'Enable', 'on');
        set(handles.textVoxSize,'Enable', 'on');
    else
		set(handles.checkboxNormalize, 'Value', 0);	
        set(handles.editBoundingBox, 'Enable', 'off', 'String', mat2str(handles.Cfg.Normalize.BoundingBox));
        set(handles.editVoxSize, 'Enable', 'off', 'String', mat2str(handles.Cfg.Normalize.VoxSize));
        set(handles.radiobuttonNormalize_EPI,'Enable', 'off', 'Value',1);
        set(handles.radiobuttonNormalize_T1,'Enable', 'off', 'Value',0);
        set(handles.radiobuttonNormalize_DARTEL,'Enable', 'off', 'Value',0);
        set(handles.checkboxIsDelFilesBeforeNormalize,'Enable', 'off', 'Value',handles.Cfg.IsDelFilesBeforeNormalize);
        set(handles.textBoundingBox,'Enable', 'off');
        set(handles.textVoxSize,'Enable', 'off');
    end
    
    if handles.Cfg.IsSmooth>0
		set(handles.checkboxSmooth, 'Value', handles.Cfg.IsSmooth==1);	
        set(handles.checkboxSmoothByDARTEL, 'Value', handles.Cfg.IsSmooth==2);	
        set(handles.editFWHM, 'Enable', 'on', 'String', mat2str(handles.Cfg.Smooth.FWHM));
        set(handles.textFWHM,'Enable', 'on');
    else
		set(handles.checkboxSmooth, 'Value', 0);	
        set(handles.checkboxSmoothByDARTEL, 'Value', 0);	
        set(handles.editFWHM, 'Enable', 'off', 'String', mat2str(handles.Cfg.Smooth.FWHM));
        set(handles.textFWHM,'Enable', 'off');
    end

    set(handles.checkboxDetrend,'Value',handles.Cfg.IsDetrend);
    
    if handles.Cfg.IsFilter==1
        set(handles.ckboxFilter, 'Value', 1);
        set(handles.edtBandLow, 'Enable', 'on', 'String', num2str(handles.Cfg.Filter.AHighPass_LowCutoff));
        set(handles.edtBandHigh, 'Enable', 'on', 'String', num2str(handles.Cfg.Filter.ALowPass_HighCutoff));
        set(handles.checkboxIsDelDetrendedFiles, 'Enable', 'on', 'Value', handles.Cfg.IsDelDetrendedFiles);
        set(handles.txtBandSep,'Enable', 'on');
    else
        set(handles.ckboxFilter, 'Value', 0);
        set(handles.edtBandLow, 'Enable', 'off', 'String', num2str(handles.Cfg.Filter.AHighPass_LowCutoff));
        set(handles.edtBandHigh, 'Enable', 'off', 'String', num2str(handles.Cfg.Filter.ALowPass_HighCutoff));
        set(handles.checkboxIsDelDetrendedFiles, 'Enable', 'off', 'Value', handles.Cfg.IsDelDetrendedFiles);
        set(handles.txtBandSep,'Enable', 'off');
    end
    
    if isequal(handles.Cfg.MaskFile, '')
        set(handles.edtMaskfile, 'Enable','off', 'String','Don''t use any Mask');
        set(handles.btnSelectMask, 'Enable','off');
        set(handles.rbtnDefaultMask,'Value',0);
        set(handles.rbtnNullMask,'Value',1);
        set(handles.rbtnUserMask,'Value',0);
    elseif isequal(handles.Cfg.MaskFile, 'Default')
        set(handles.edtMaskfile, 'Enable','off', 'String','Use Default Mask');
        set(handles.btnSelectMask, 'Enable','off');
        set(handles.rbtnDefaultMask,'Value',1);
        set(handles.rbtnNullMask,'Value',0);
        set(handles.rbtnUserMask,'Value',0);
    else
        set(handles.edtMaskfile,'Enable','on', 'String',handles.Cfg.MaskFile);
        set(handles.btnSelectMask, 'Enable','on');
        set(handles.rbtnDefaultMask,'Value',0);
        set(handles.rbtnNullMask,'Value',0);
        set(handles.rbtnUserMask,'Value',1);
    end
    
    if handles.Cfg.IsCalReHo==1
        set(handles.checkboxCalReHo, 'Value', 1);
        set(handles.radiobuttonReHo7voxels, 'Enable', 'on', 'Value', handles.Cfg.CalReHo.ClusterNVoxel == 7);
        set(handles.radiobuttonReHo19voxels, 'Enable', 'on', 'Value', handles.Cfg.CalReHo.ClusterNVoxel == 19);
        set(handles.radiobuttonReHo27voxels, 'Enable', 'on', 'Value', handles.Cfg.CalReHo.ClusterNVoxel == 27);
        set(handles.checkboxsmReHo, 'Enable', 'on', 'Value', handles.Cfg.CalReHo.smReHo);
        set(handles.checkboxmReHo_1, 'Enable', 'on', 'Value', handles.Cfg.CalReHo.mReHo_1);
        set(handles.textReHoCluster,'Enable', 'on');
    else
        set(handles.checkboxCalReHo, 'Value', 0);
        set(handles.radiobuttonReHo7voxels, 'Enable', 'off', 'Value', handles.Cfg.CalReHo.ClusterNVoxel == 7);
        set(handles.radiobuttonReHo19voxels, 'Enable', 'off', 'Value', handles.Cfg.CalReHo.ClusterNVoxel == 19);
        set(handles.radiobuttonReHo27voxels, 'Enable', 'off', 'Value', handles.Cfg.CalReHo.ClusterNVoxel == 27);
        set(handles.checkboxsmReHo, 'Enable', 'off', 'Value', handles.Cfg.CalReHo.smReHo);
        set(handles.checkboxmReHo_1, 'Enable', 'off', 'Value', handles.Cfg.CalReHo.mReHo_1);
        set(handles.textReHoCluster,'Enable', 'off');
    end
    
    if (handles.Cfg.IsCalALFF==1) || (handles.Cfg.IsCalfALFF==1)
        set(handles.checkboxCalALFF, 'Value', handles.Cfg.IsCalALFF);
        set(handles.checkboxCalfALFF, 'Value', handles.Cfg.IsCalfALFF);
        set(handles.edtfAlffBandLow, 'Enable', 'on', 'String', num2str(handles.Cfg.CalALFF.AHighPass_LowCutoff));
        set(handles.edtfAlffBandHigh, 'Enable', 'on', 'String', num2str(handles.Cfg.CalALFF.ALowPass_HighCutoff));
        set(handles.checkboxmALFF_1, 'Enable', 'on', 'Value', handles.Cfg.CalALFF.mALFF_1);
        set(handles.txtfAlffBand,'Enable', 'on');
        set(handles.txtfAlffBandSep,'Enable', 'on');
    else
        set(handles.checkboxCalALFF, 'Value', handles.Cfg.IsCalALFF);
        set(handles.checkboxCalfALFF, 'Value', handles.Cfg.IsCalfALFF);
        set(handles.edtfAlffBandLow, 'Enable', 'off', 'String', num2str(handles.Cfg.CalALFF.AHighPass_LowCutoff));
        set(handles.edtfAlffBandHigh, 'Enable', 'off', 'String', num2str(handles.Cfg.CalALFF.ALowPass_HighCutoff));
        set(handles.checkboxmALFF_1, 'Enable', 'off', 'Value', handles.Cfg.CalALFF.mALFF_1);
        set(handles.txtfAlffBand,'Enable', 'off');
        set(handles.txtfAlffBandSep,'Enable', 'off');
    end
    
    if handles.Cfg.IsCovremove==1
        set(handles.checkboxCovremove, 'Value', 1);
        set(handles.checkboxCovremoveHeadMotion, 'Enable', 'on', 'Value', handles.Cfg.Covremove.HeadMotion);
        set(handles.checkboxCovremoveWholeBrain, 'Enable', 'on', 'Value', handles.Cfg.Covremove.WholeBrain);
        set(handles.checkboxCovremoveWhiteMatter, 'Enable', 'on', 'Value', handles.Cfg.Covremove.WhiteMatter);
        set(handles.checkboxCovremoveCSF, 'Enable', 'on', 'Value', handles.Cfg.Covremove.CSF);
        set(handles.checkboxOtherCovariates, 'Enable', 'on', 'Value', ~isempty(handles.Cfg.Covremove.OtherCovariatesROI));
    else
        set(handles.checkboxCovremove, 'Value', 0);
        set(handles.checkboxCovremoveHeadMotion, 'Enable', 'off', 'Value', handles.Cfg.Covremove.HeadMotion);
        set(handles.checkboxCovremoveWholeBrain, 'Enable', 'off', 'Value', handles.Cfg.Covremove.WholeBrain);
        set(handles.checkboxCovremoveWhiteMatter, 'Enable', 'off', 'Value', handles.Cfg.Covremove.WhiteMatter);
        set(handles.checkboxCovremoveCSF, 'Enable', 'off', 'Value', handles.Cfg.Covremove.CSF);
        set(handles.checkboxOtherCovariates, 'Enable', 'off', 'Value', ~isempty(handles.Cfg.Covremove.OtherCovariatesROI));
    end
    
    if (handles.Cfg.IsExtractRESTdefinedROITC==1) || (handles.Cfg.IsCalFC==1)
        set(handles.checkboxExtractRESTdefinedROITC, 'Value', handles.Cfg.IsExtractRESTdefinedROITC);
        set(handles.checkboxCalFC, 'Value', handles.Cfg.IsCalFC);
        set(handles.pushbuttonDefineROI, 'Enable', 'on');
        set(handles.checkboxDefineROIInteractively, 'Enable', 'on', 'Value', handles.Cfg.IsDefineROIInteractively);
    else
        set(handles.checkboxExtractRESTdefinedROITC, 'Value', handles.Cfg.IsExtractRESTdefinedROITC);
        set(handles.checkboxCalFC, 'Value', handles.Cfg.IsCalFC);
        set(handles.pushbuttonDefineROI, 'Enable', 'off');
        set(handles.checkboxDefineROIInteractively, 'Enable', 'off', 'Value', handles.Cfg.IsDefineROIInteractively);
    end
    
    set(handles.checkboxExtractAALTC, 'Value', handles.Cfg.IsExtractAALTC);
    
    set(handles.checkboxWarpMasksIntoIndividualSpace, 'Value', handles.Cfg.IsWarpMasksIntoIndividualSpace);
    set(handles.editFunctionalSessionNumber ,'String', num2str(handles.Cfg.FunctionalSessionNumber));	
    set(handles.editStartingDirName ,'String', handles.Cfg.StartingDirName);

    
    drawnow;
   
